from django.contrib import admin
from django.utils.html import format_html
from django.utils.translation import ugettext_lazy as _

from ..models.app_text import AppText, AppTextTranslation


class TranslationAppTextInline(admin.TabularInline):
    model = AppTextTranslation
    fields = ('language_code', 'translation')
    extra = 0


class AppTextAdmin(admin.ModelAdmin):
    list_display = ('text_key','checked')
    fields = ('text_key','screenshot_url', 'checked', "get_image_preview")
    readonly_fields = ("get_image_preview",)

    def get_image_preview(self, obj):
        screenshot_url = '/media/' + str(obj.screenshot_url)
        if obj.pk:
            return format_html('<img src="{url}" title="{url}" width="30%" height="30%"/> ' \
                               .format(url=screenshot_url))

    get_image_preview.short_description = _("Image Preview")

    inlines = [
        TranslationAppTextInline,
    ]


admin.site.register(AppText, AppTextAdmin)
admin.autodiscover()
