from django.db import models
from django.utils.translation import ugettext_lazy as _


class Sport(models.Model):
    sport_id = models.AutoField(primary_key = True)
    language_code = models.CharField(max_length=2,default="hu")
    sport_name = models.CharField(max_length=100)

    class Meta:
        db_table = 'sport_translation'


class Customer(models.Model):
    customer_id = models.BigAutoField(primary_key=True)
    name = models.CharField(max_length=100, help_text='Last name', verbose_name=_("name"))
    firstname = models.CharField(max_length=100, help_text='First name', verbose_name=_("firstname"))
    email = models.CharField(max_length=100)
    sport = models.ForeignKey(Sport, on_delete=models.CASCADE)
    goal = models.CharField(max_length=20)
    fitness_level = models.CharField(max_length=20)
    date_add = models.DateField()
    synced_date = models.DateTimeField(blank=True,null=True)

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    class Meta:
        db_table = 'customer'
        verbose_name = _("Customer")
        verbose_name_plural = _("Customers")
        app_label = 'controlling'

    def __str__(self):
        return self.name
